==> testsuite-3.0.22-beta1.tar.gz: testsuite/src/TestMenuService.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Test Suite Services.
 */
class TestMenuService {

  /**
   * Load Resource Service.
   *
   * @var \Drupal\testsuite\LoadResourceService
   */
  protected $loadResourceService;

  /**
   * Load Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Load Resource Service.
   *
   * @param \Drupal\testsuite\LoadResourceService $loadResourceService
   *   The load resource service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config service.
   */
  public function __construct(
    LoadResourceService $loadResourceService,
    ConfigFactoryInterface $configFactory
  ) {
    $this->loadResourceService = $loadResourceService;
    $this->configFactory = $configFactory;
  }

  /**
   * Creates the top two lonks PHPUnit and Custom.
   *
   * @return array
   *   The render array of links.
   */
  public function buildTestsMenu() {
    $customUrl = Url::fromRoute('testsuite.custom');
    $phpunitUrl = Url::fromRoute('testsuite.phpunit', [
      'area' => 'contrib',
      'module' => 'testsuite',
    ]);

    $custom_link = Link::fromTextAndUrl('Custom', $customUrl);
    $phpunit_link = Link::fromTextAndUrl('PHPUnit', $phpunitUrl);

    $list_items = [
      $phpunit_link,
      $custom_link,
    ];

    $output['page_menu'] = [
      '#theme' => 'item_list',
      '#type' => 'ul',
      '#items' => $list_items,
      '#attached' => [
        'library' => [
          'testsuite/menu',
        ],
      ],
      '#attributes' => ['class' => 'testsuite__list'],
      '#prefix' => '<div class="test-suite-page-menu-container">',
      '#suffix' => '</div>',

    ];

    return $output;
  }

  /**
   * Changes machine_name to Machine Name.
   *
   * @param string $machine_name
   *   The machine_name.
   *
   * @return string
   *   The name.
   */
  private function createName($machine_name) {
    $parts = explode("_", $machine_name);
    return ucwords(implode(" ", $parts));
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @return array
   *   The array of files to create classes with.
   */
  public function buildModuleMenu() {
    $enabledTests = array();
    $config = $this->configFactory->get('testsuite.settings');
    foreach ($config->get('testsuite_loaded_test_types') as $test => $enabled) {
      if ($enabled) array_push($enabledTests, $test);
    }

    $modulesArray = $this->loadResourceService->getResource('menu', 'phpunit', 'all', 'all', 'all');
    $list_items = [];
    $all_items = [];
    foreach ($modulesArray as $area => $modules) {
      $items = [];
      $has_mods = FALSE;

      if (count($modules) > 0) {
        foreach ($modules as $module => $testDirectory) {
          $directories = [];
          $has_dirs = FALSE;

          foreach ($testDirectory as $directory) {
            if (in_array($directory, $enabledTests)) {
              if (!in_array($directory, $all_items)) {
                $all_items[] = $directory;
              }
              $link = Link::fromTextAndUrl(
                    $directory,
                    Url::fromRoute(
                        'testsuite.phpunit',
                        [
                          'area' => $area,
                          'module' => $module,
                          'directory' => $directory,
                        ]
                    )
                )->toRenderable();
              $link['#attributes'] = [
                'class' => ['test-suite-directory-links'],
              ];
              $directories[] = $link;
              $has_dirs = TRUE;
            }
          }

          if ($has_dirs) {
            $items[] = [
              '#markup' => '<a href="#" class="test-suite-module-links">' . $this->createName($module) . '<i class="arrow down"></i></a>',
              'children' => $directories,
            ];
            $has_mods = TRUE;
          }
        }

        if ($has_mods) {
          $list_items[] = [
            '#markup' => '<a href="#" class="test-suite-area-links">' . ucwords($area) . '</a>',
            'children' => $items,
          ];
        }
      }
    }

    $output['modules_menu'] = [
      '#theme' => 'item_list',
      '#type' => 'ul',
      '#attributes' => ['class' => 'testsuite__list'],
      '#items' => $list_items,
      '#prefix' => '<div class="test-suite-module-menu-container">',
      '#suffix' => '</div>',
    ];

    return $output;
  }

}

==> testsuite-3.0.40-beta1.tar.gz: testsuite/src/TestMenuService.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Test Suite Services.
 */
class TestMenuService {

  /**
   * Load Resource Service.
   *
   * @var \Drupal\testsuite\LoadResourceService
   */
  protected $loadResourceService;

  /**
   * Load Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Load Resource Service.
   *
   * @param \Drupal\testsuite\LoadResourceService $loadResourceService
   *   The load resource service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config service.
   */
  public function __construct(
    LoadResourceService $loadResourceService,
    ConfigFactoryInterface $configFactory
  ) {
    $this->loadResourceService = $loadResourceService;
    $this->configFactory = $configFactory;
  }

  /**
   * Creates the top two lonks PHPUnit and Custom.
   *
   * @return array
   *   The render array of links.
   */
  public function buildTestsMenu() {
    $customUrl = Url::fromRoute('testsuite.custom');
    $phpunitUrl = Url::fromRoute('testsuite.phpunit', [
      'area' => 'contrib',
      'module' => 'testsuite',
    ]);

    $custom_link = Link::fromTextAndUrl('Custom', $customUrl);
    $phpunit_link = Link::fromTextAndUrl('PHPUnit', $phpunitUrl);

    $list_items = [
      $phpunit_link,
      $custom_link,
    ];

    $output['page_menu'] = [
      '#theme' => 'item_list',
      '#type' => 'ul',
      '#items' => $list_items,
      '#attached' => [
        'library' => [
          'testsuite/menu',
        ],
      ],
      '#attributes' => ['class' => 'testsuite__list'],
      '#prefix' => '<div class="test-suite-page-menu-container">',
      '#suffix' => '</div>',

    ];

    return $output;
  }

  /**
   * Changes machine_name to Machine Name.
   *
   * @param string $machine_name
   *   The machine_name.
   *
   * @return string
   *   The name.
   */
  private function createName($machine_name) {
    $parts = explode("_", $machine_name);
    return ucwords(implode(" ", $parts));
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @return array
   *   The array of files to create classes with.
   */
  public function buildModuleMenu() {
    $enabledTests = [];
    $config = $this->configFactory->get('testsuite.settings');
    foreach ($config->get('testsuite_loaded_test_types') as $test => $enabled) {
      if ($enabled) {
        array_push($enabledTests, $test);
      }
    }

    $modulesArray = $this->loadResourceService->getResource('menu', 'phpunit', 'all', 'all', 'all');
    $list_items = [];
    $all_items = [];
    foreach ($modulesArray as $area => $modules) {
      $items = [];
      $has_mods = FALSE;

      if (count($modules) > 0) {
        foreach ($modules as $module => $testDirectory) {
          $directories = [];
          $has_dirs = FALSE;

          foreach ($testDirectory as $directory) {
            if (in_array($directory, $enabledTests)) {
              if (!in_array($directory, $all_items)) {
                $all_items[] = $directory;
              }
              $link = Link::fromTextAndUrl(
                    $directory,
                    Url::fromRoute(
                        'testsuite.phpunit',
                        [
                          'area' => $area,
                          'module' => $module,
                          'directory' => $directory,
                        ]
                    )
                )->toRenderable();
              $link['#attributes'] = [
                'class' => ['test-suite-directory-links'],
              ];
              $directories[] = $link;
              $has_dirs = TRUE;
            }
          }

          if ($has_dirs) {
            $items[] = [
              '#markup' => '<a href="#" class="test-suite-module-links">' . $this->createName($module) . '<i class="arrow down"></i></a>',
              'children' => $directories,
            ];
            $has_mods = TRUE;
          }
        }

        if ($has_mods) {
          $list_items[] = [
            '#markup' => '<a href="#" class="test-suite-area-links">' . ucwords($area) . '</a>',
            'children' => $items,
          ];
        }
      }
    }

    $output['modules_menu'] = [
      '#theme' => 'item_list',
      '#type' => 'ul',
      '#attributes' => ['class' => 'testsuite__list'],
      '#items' => $list_items,
      '#prefix' => '<div class="test-suite-module-menu-container">',
      '#suffix' => '</div>',
    ];

    return $output;
  }

}
